# scorefast-lib

Goal of this repository is to create in-house and client side libraries.

## ScoreFast Data Transfer

ScoreFast Data transfer is responsible for transferring the data from client or server machine to ScoreData S3.

### Run scorefast transfer tool
 *sbin/transfer-{os} --conf datatransfer/conf/config.conf*

